pub struct ApprovalReq {
pub subject_id: DigestIdentifier,
pub sn: u64,
pub gov_version: u64,
pub patch: ValueWrapper,
pub signer: PublicKey,
}Expand description
A struct representing an approval request.
Fields
subject_id: DigestIdentifierThe signed event request.
sn: u64The sequence number of the event.
gov_version: u64The version of the governance contract.
patch: ValueWrapperThe patch to apply to the state.
signer: PublicKeyTrait Implementations
Sourceimpl BorshDeserialize for ApprovalReq
impl BorshDeserialize for ApprovalReq
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for ApprovalReq
impl BorshSerialize for ApprovalReq
Sourceimpl Clone for ApprovalReq
impl Clone for ApprovalReq
Sourcefn clone(&self) -> ApprovalReq
fn clone(&self) -> ApprovalReq
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ApprovalReq
impl Debug for ApprovalReq
Sourceimpl<'de> Deserialize<'de> for ApprovalReq
impl<'de> Deserialize<'de> for ApprovalReq
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for ApprovalReq
impl PartialEq for ApprovalReq
Sourceimpl Serialize for ApprovalReq
impl Serialize for ApprovalReq
impl Eq for ApprovalReq
impl StructuralPartialEq for ApprovalReq