Module config

Module config 

Configuration module

Structs

AveExternalDBConfig
AveInternalDBConfig
Config
Node configuration.
GovernanceSyncConfig
LoggingConfig
LoggingOutput
RebootSyncConfig
ResolvedSpec
Resolved machine parameters ready to be consumed by any tuned subsystem.
SinkAuth
SinkConfig
SinkServer
SyncConfig
TrackerSyncConfig
UpdateSyncConfig

Enums

AveExternalDBFeatureConfig
Database configuration.
AveInternalDBFeatureConfig
Database configuration.
LoggingRotation
MachineProfile
Predefined instance profiles with fixed vCPU and RAM. They only exist to provide convenient default values — the actual wasmtime tuning is derived from the resolved ram_mb and cpu_cores.
MachineSpec
How to size the contract execution environment.
SinkQueuePolicy
SinkRoutingStrategy

Functions

resolve_spec
Resolve the final sizing parameters from a MachineSpec: