pub struct GovernanceSyncConfig {
pub interval_secs: u64,
pub sample_size: usize,
pub response_timeout_secs: u64,
}Fields
interval_secs: u64Seconds between version sync rounds for governance service nodes.
sample_size: usizeNumber of peers sampled on each version sync round.
response_timeout_secs: u64Seconds to wait for responses during a version sync round.