pub struct ContractArtifactRecord {
pub contract_hash: DigestIdentifier,
pub manifest_hash: DigestIdentifier,
pub wasm_hash: DigestIdentifier,
pub cwasm_hash: DigestIdentifier,
pub engine_fingerprint: DigestIdentifier,
pub toolchain_fingerprint: DigestIdentifier,
}Fields
contract_hash: DigestIdentifiermanifest_hash: DigestIdentifierwasm_hash: DigestIdentifiercwasm_hash: DigestIdentifierengine_fingerprint: DigestIdentifiertoolchain_fingerprint: DigestIdentifierTrait Implementations
Sourceimpl BorshDeserialize for ContractArtifactRecord
impl BorshDeserialize for ContractArtifactRecord
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for ContractArtifactRecord
impl Clone for ContractArtifactRecord
Sourcefn clone(&self) -> ContractArtifactRecord
fn clone(&self) -> ContractArtifactRecord
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ContractArtifactRecord
impl Debug for ContractArtifactRecord
Sourceimpl<'de> Deserialize<'de> for ContractArtifactRecord
impl<'de> Deserialize<'de> for ContractArtifactRecord
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more