pub struct ContractResult {
pub success: bool,
pub error: String,
}Fields
success: boolerror: StringTrait Implementations
Sourceimpl BorshDeserialize for ContractResult
impl BorshDeserialize for ContractResult
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for ContractResult
impl BorshSerialize for ContractResult
Sourceimpl Clone for ContractResult
impl Clone for ContractResult
Sourcefn clone(&self) -> ContractResult
fn clone(&self) -> ContractResult
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ContractResult
impl Debug for ContractResult
Sourceimpl<'de> Deserialize<'de> for ContractResult
impl<'de> Deserialize<'de> for ContractResult
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more