pub struct SubjectContext {
pub subject_id: DigestIdentifier,
pub governance_id: DigestIdentifier,
pub schema_id: SchemaType,
pub is_owner: bool,
pub namespace: Namespace,
}Expand description
A struct representing the context in which the evaluation is being performed.
Fields
subject_id: DigestIdentifiergovernance_id: DigestIdentifierschema_id: SchemaTypeis_owner: boolnamespace: NamespaceTrait Implementations
Sourceimpl BorshDeserialize for SubjectContext
impl BorshDeserialize for SubjectContext
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for SubjectContext
impl BorshSerialize for SubjectContext
Sourceimpl Clone for SubjectContext
impl Clone for SubjectContext
Sourcefn clone(&self) -> SubjectContext
fn clone(&self) -> SubjectContext
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SubjectContext
impl Debug for SubjectContext
Sourceimpl<'de> Deserialize<'de> for SubjectContext
impl<'de> Deserialize<'de> for SubjectContext
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for SubjectContext
impl PartialEq for SubjectContext
Sourceimpl Serialize for SubjectContext
impl Serialize for SubjectContext
impl Eq for SubjectContext
impl StructuralPartialEq for SubjectContext