pub enum EvaluationResult {
Ok {
response: EvaluatorResponse,
eval_req_hash: DigestIdentifier,
req_subject_data_hash: DigestIdentifier,
},
Error {
error: EvaluatorError,
eval_req_hash: DigestIdentifier,
req_subject_data_hash: DigestIdentifier,
},
}Variants
Ok
Fields

response: EvaluatorResponse
eval_req_hash: DigestIdentifier
req_subject_data_hash: DigestIdentifierError
Fields

error: EvaluatorError
eval_req_hash: DigestIdentifier
req_subject_data_hash: DigestIdentifierTrait Implementations
Sourceimpl BorshDeserialize for EvaluationResult
impl BorshDeserialize for EvaluationResult
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for EvaluationResult
impl BorshSerialize for EvaluationResult
Sourceimpl Clone for EvaluationResult
impl Clone for EvaluationResult
Sourcefn clone(&self) -> EvaluationResult
fn clone(&self) -> EvaluationResult
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EvaluationResult
impl Debug for EvaluationResult
Sourceimpl<'de> Deserialize<'de> for EvaluationResult
impl<'de> Deserialize<'de> for EvaluationResult
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl EnumExt for EvaluationResult
impl EnumExt for EvaluationResult
Sourceimpl PartialEq for EvaluationResult
impl PartialEq for EvaluationResult
Sourceimpl Serialize for EvaluationResult
impl Serialize for EvaluationResult
impl Eq for EvaluationResult
impl StructuralPartialEq for EvaluationResult