pub struct EvaluatorResponse {
pub patch: ValueWrapper,
pub properties_hash: DigestIdentifier,
pub appr_required: bool,
}Fields
patch: ValueWrapperThe patch to apply to the state.
properties_hash: DigestIdentifierThe hash of the state after applying the patch.
appr_required: boolWhether approval is required for the evaluation to be applied to the state.