GovernanceData

Struct GovernanceData 

pub struct GovernanceData {
    pub version: u64,
    pub members: BTreeMap<MemberName, PublicKey>,
    pub roles_gov: RolesGov,
    pub policies_gov: PolicyGov,
    pub schemas: BTreeMap<SchemaType, Schema>,
    pub roles_schema: BTreeMap<SchemaType, RolesSchema>,
    pub roles_tracker_schemas: RolesTrackerSchemas,
    pub policies_schema: BTreeMap<SchemaType, PolicySchema>,
}

Fields

version: u64members: BTreeMap<MemberName, PublicKey>roles_gov: RolesGovpolicies_gov: PolicyGovschemas: BTreeMap<SchemaType, Schema>roles_schema: BTreeMap<SchemaType, RolesSchema>roles_tracker_schemas: RolesTrackerSchemaspolicies_schema: BTreeMap<SchemaType, PolicySchema>

Implementations

Source

impl GovernanceData

pub fn new(owner_key: PublicKey) -> Self

pub fn roles_update_remove_confirm( &self, old_owner_key: &PublicKey, new_owner_key: &PublicKey, ) -> RolesUpdateConfirm

pub fn roles_update_remove_fact( &self, remove_members: Option<HashSet<String>>, remove_schemas: Option<HashSet<SchemaType>>, ) -> RolesUpdateRemove

pub fn remove_schema(&mut self, remove_schemas: HashSet<SchemaType>)

pub fn add_schema(&mut self, add_schema: HashSet<SchemaType>)

pub fn remove_member_role(&mut self, remove_members: &Vec<MemberName>)

pub fn update_name_role(&mut self, old_name: String)

pub fn to_value_wrapper(&self) -> ValueWrapper

pub fn check_basic_gov(&self) -> bool

pub fn get_init_state( &self, schema_id: &SchemaType, ) -> Result<ValueWrapper, GovernanceError>

Get the initial state for GovernanceData model

Arguments
  • schema_id - The identifier of the Schema.
Returns
Errors
  • GovernanceError - If the schema is not found.
pub fn has_this_role(&self, data: HashThisRole) -> bool

Check if the user has a role.

Arguments
  • user - The user id.
  • [Roles] - The role.
  • schema - The schema id from Schema.
  • Namespace - The namespace.
pub fn get_signers( &self, role: RoleTypes, schema_id: &SchemaType, namespace: Namespace, ) -> (HashSet<PublicKey>, bool)

Gets the signers for the request stage.

Arguments
  • [Roles] - The role.
  • schema_id - The schema id from Schema.
  • Namespace - The namespace.
Returns
  • (HashSet<PublicKey>, bool) - The set of key identifiers and a flag indicating if the user is not a member.
pub fn get_witnesses( &self, data: WitnessesData, ) -> Result<HashSet<PublicKey>, GovernanceError>

pub fn get_quorum_and_signers( &self, role: ProtocolTypes, schema_id: &SchemaType, namespace: Namespace, ) -> Result<(HashSet<PublicKey>, Quorum), GovernanceError>

Get the quorum and signers for the role and schema.

Arguments
  • [Roles] - The role.
  • schema_id - The schema id from Schema.
  • Namespace - The namespace.
Returns
  • (HashSet<PublicKey>, Quorum) - The set of key identifiers and the quorum.
pub fn schemas_name( &self, role: ProtocolTypes, key: &PublicKey, ) -> BTreeSet<SchemaType>

pub fn schemas_namespace( &self, role: ProtocolTypes, key: &PublicKey, ) -> BTreeMap<SchemaType, Vec<Namespace>>

pub fn schema_creators_namespace( &self, schema_namespaces: BTreeMap<SchemaType, Vec<Namespace>>, ) -> BTreeMap<SchemaType, BTreeMap<PublicKey, BTreeSet<Namespace>>>

pub fn governance_issuers(&self) -> (BTreeSet<PublicKey>, bool)

pub fn schema_issuers_namespace( &self, schema_namespaces: BTreeMap<SchemaType, Vec<Namespace>>, ) -> BTreeMap<SchemaType, (BTreeMap<PublicKey, BTreeSet<Namespace>>, bool)>

pub fn schemas( &self, role: ProtocolTypes, key: &PublicKey, ) -> BTreeMap<SchemaType, Schema>

pub fn schemas_init_value( &self, role: ProtocolTypes, key: &PublicKey, ) -> BTreeMap<SchemaType, ValueWrapper>

pub fn is_member(&self, key: &PublicKey) -> bool

Check if the key is a member.