pub struct CreatorWitness {
pub name: String,
pub viewpoints: BTreeSet<String>,
}Fields
name: Stringviewpoints: BTreeSet<String>Trait Implementations
Sourceimpl BorshDeserialize for CreatorWitness
impl BorshDeserialize for CreatorWitness
fn deserialize_reader<__R>(reader: &mut __R) -> Result<CreatorWitness, Error>where
__R: Read,
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for CreatorWitness
impl BorshSerialize for CreatorWitness
Sourceimpl Clone for CreatorWitness
impl Clone for CreatorWitness
Sourcefn clone(&self) -> CreatorWitness
fn clone(&self) -> CreatorWitness
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CreatorWitness
impl Debug for CreatorWitness
Sourceimpl<'de> Deserialize<'de> for CreatorWitness
impl<'de> Deserialize<'de> for CreatorWitness
Sourcefn deserialize<D>(
deserializer: D,
) -> Result<CreatorWitness, <D as Deserializer<'de>>::Error>where
D: Deserializer<'de>,
fn deserialize<D>(
deserializer: D,
) -> Result<CreatorWitness, <D as Deserializer<'de>>::Error>where
D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for CreatorWitness
impl Hash for CreatorWitness
Sourceimpl Ord for CreatorWitness
impl Ord for CreatorWitness
Sourcefn cmp(&self, other: &CreatorWitness) -> Ordering
fn cmp(&self, other: &CreatorWitness) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for CreatorWitness
impl PartialEq for CreatorWitness
Sourceimpl PartialOrd for CreatorWitness
impl PartialOrd for CreatorWitness
Sourceimpl Serialize for CreatorWitness
impl Serialize for CreatorWitness
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl Eq for CreatorWitness
impl StructuralPartialEq for CreatorWitness