pub struct Role {
pub name: String,
pub namespace: Namespace,
}Fields
name: Stringnamespace: NamespaceTrait Implementations
Sourceimpl BorshDeserialize for Role
impl BorshDeserialize for Role
fn deserialize_reader<__R>(reader: &mut __R) -> Result<Role, Error>where
__R: Read,
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for Role
impl BorshSerialize for Role
Sourceimpl<'de> Deserialize<'de> for Role
impl<'de> Deserialize<'de> for Role
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<Role, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<Role, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Ord for Role
impl Ord for Role
Sourceimpl PartialOrd for Role
impl PartialOrd for Role
Sourceimpl Serialize for Role
impl Serialize for Role
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl Eq for Role
impl StructuralPartialEq for Role