pub struct RoleGovIssuer {
pub signers: BTreeSet<MemberName>,
pub any: bool,
}Fields
signers: BTreeSet<MemberName>any: boolTrait Implementations
Sourceimpl BorshDeserialize for RoleGovIssuer
impl BorshDeserialize for RoleGovIssuer
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for RoleGovIssuer
impl BorshSerialize for RoleGovIssuer
Sourceimpl Clone for RoleGovIssuer
impl Clone for RoleGovIssuer
Sourcefn clone(&self) -> RoleGovIssuer
fn clone(&self) -> RoleGovIssuer
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RoleGovIssuer
impl Debug for RoleGovIssuer
Sourceimpl Default for RoleGovIssuer
impl Default for RoleGovIssuer
Sourcefn default() -> RoleGovIssuer
fn default() -> RoleGovIssuer
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for RoleGovIssuer
impl<'de> Deserialize<'de> for RoleGovIssuer
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for RoleGovIssuer
impl PartialEq for RoleGovIssuer
Sourceimpl Serialize for RoleGovIssuer
impl Serialize for RoleGovIssuer
impl Eq for RoleGovIssuer
impl StructuralPartialEq for RoleGovIssuer