pub struct RoleSchemaIssuer {
pub signers: BTreeSet<Role>,
pub any: bool,
}Fields
signers: BTreeSet<Role>any: boolTrait Implementations
Sourceimpl BorshDeserialize for RoleSchemaIssuer
impl BorshDeserialize for RoleSchemaIssuer
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for RoleSchemaIssuer
impl BorshSerialize for RoleSchemaIssuer
Sourceimpl Clone for RoleSchemaIssuer
impl Clone for RoleSchemaIssuer
Sourcefn clone(&self) -> RoleSchemaIssuer
fn clone(&self) -> RoleSchemaIssuer
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RoleSchemaIssuer
impl Debug for RoleSchemaIssuer
Sourceimpl Default for RoleSchemaIssuer
impl Default for RoleSchemaIssuer
Sourcefn default() -> RoleSchemaIssuer
fn default() -> RoleSchemaIssuer
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for RoleSchemaIssuer
impl<'de> Deserialize<'de> for RoleSchemaIssuer
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for RoleSchemaIssuer
impl PartialEq for RoleSchemaIssuer
Sourceimpl Serialize for RoleSchemaIssuer
impl Serialize for RoleSchemaIssuer
impl Eq for RoleSchemaIssuer
impl StructuralPartialEq for RoleSchemaIssuer