pub struct Schema {
pub initial_value: ValueWrapper,
pub contract: String,
pub viewpoints: BTreeSet<String>,
}Expand description
Governance schema.
Fields
initial_value: ValueWrappercontract: Stringviewpoints: BTreeSet<String>Trait Implementations
Sourceimpl BorshDeserialize for Schema
impl BorshDeserialize for Schema
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for Schema
impl BorshSerialize for Schema
Sourceimpl<'de> Deserialize<'de> for Schema
impl<'de> Deserialize<'de> for Schema
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for Schema
impl StructuralPartialEq for Schema