pub struct RoleData {
pub key: PublicKey,
pub namespace: Namespace,
}Fields
key: PublicKeynamespace: NamespaceTrait Implementations
Sourceimpl BorshDeserialize for RoleData
impl BorshDeserialize for RoleData
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for RoleData
impl BorshSerialize for RoleData
Sourceimpl<'de> Deserialize<'de> for RoleData
impl<'de> Deserialize<'de> for RoleData
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Ord for RoleData
impl Ord for RoleData
Sourceimpl PartialOrd for RoleData
impl PartialOrd for RoleData
impl Eq for RoleData
impl StructuralPartialEq for RoleData