pub struct RoleDataRegister {
pub workers: HashSet<PublicKey>,
pub quorum: Quorum,
}Fields
workers: HashSet<PublicKey>quorum: QuorumTrait Implementations
Sourceimpl BorshDeserialize for RoleDataRegister
impl BorshDeserialize for RoleDataRegister
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for RoleDataRegister
impl BorshSerialize for RoleDataRegister
Sourceimpl Clone for RoleDataRegister
impl Clone for RoleDataRegister
Sourcefn clone(&self) -> RoleDataRegister
fn clone(&self) -> RoleDataRegister
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RoleDataRegister
impl Debug for RoleDataRegister
Sourceimpl<'de> Deserialize<'de> for RoleDataRegister
impl<'de> Deserialize<'de> for RoleDataRegister
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more