pub struct UpdateQuorum {
pub schema_id: SchemaType,
pub quorum: Quorum,
}Fields
schema_id: SchemaTypequorum: QuorumTrait Implementations
Sourceimpl BorshDeserialize for UpdateQuorum
impl BorshDeserialize for UpdateQuorum
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for UpdateQuorum
impl BorshSerialize for UpdateQuorum
Sourceimpl Clone for UpdateQuorum
impl Clone for UpdateQuorum
Sourcefn clone(&self) -> UpdateQuorum
fn clone(&self) -> UpdateQuorum
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for UpdateQuorum
impl Debug for UpdateQuorum
Sourceimpl<'de> Deserialize<'de> for UpdateQuorum
impl<'de> Deserialize<'de> for UpdateQuorum
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more