Module contract

Module contract 

Structs

MemoryManager
WasmLimits
Resolved wasmtime resource limits, ready to configure the engine and stores.
WasmRuntime
Wasmtime engine and resource limits bundled together.

Enums

ContractError

Constants

MAX_FUEL
MAX_FUEL_COMPILATION

Functions

create_secure_wasmtime_config
Creates a secure Wasmtime engine configuration scaled to the given limits.
generate_linker
resolve_wasm_limits
Resolve wasmtime resource limits from a MachineSpec: