pub struct TrackerStoredVisibilityRange {
pub from_sn: u64,
pub to_sn: Option<u64>,
pub visibility: TrackerStoredVisibility,
}Fields
from_sn: u64to_sn: Option<u64>visibility: TrackerStoredVisibilityTrait Implementations
Sourceimpl BorshDeserialize for TrackerStoredVisibilityRange
impl BorshDeserialize for TrackerStoredVisibilityRange
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for TrackerStoredVisibilityRange
impl Clone for TrackerStoredVisibilityRange
Sourcefn clone(&self) -> TrackerStoredVisibilityRange
fn clone(&self) -> TrackerStoredVisibilityRange
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TrackerStoredVisibilityRange
impl Debug for TrackerStoredVisibilityRange
Sourceimpl<'de> Deserialize<'de> for TrackerStoredVisibilityRange
impl<'de> Deserialize<'de> for TrackerStoredVisibilityRange
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<TrackerStoredVisibilityRange> for TrackerStoredVisibilityRangeDB
impl From<TrackerStoredVisibilityRange> for TrackerStoredVisibilityRangeDB
Sourcefn from(value: TrackerStoredVisibilityRange) -> Self
fn from(value: TrackerStoredVisibilityRange) -> Self
Converts to this type from the input type.
Sourceimpl PartialEq for TrackerStoredVisibilityRange
impl PartialEq for TrackerStoredVisibilityRange
Sourcefn eq(&self, other: &TrackerStoredVisibilityRange) -> bool
fn eq(&self, other: &TrackerStoredVisibilityRange) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for TrackerStoredVisibilityRange
impl StructuralPartialEq for TrackerStoredVisibilityRange