pub struct LedgerHash {
pub gov_version: u64,
pub sn: u64,
pub prev_ledger_event_hash: DigestIdentifier,
pub protocols_hash: DigestIdentifier,
}Fields
gov_version: u64sn: u64prev_ledger_event_hash: DigestIdentifierprotocols_hash: DigestIdentifierTrait Implementations
Sourceimpl BorshDeserialize for LedgerHash
impl BorshDeserialize for LedgerHash
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for LedgerHash
impl BorshSerialize for LedgerHash
Sourceimpl Clone for LedgerHash
impl Clone for LedgerHash
Sourcefn clone(&self) -> LedgerHash
fn clone(&self) -> LedgerHash
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LedgerHash
impl Debug for LedgerHash
Sourceimpl<'de> Deserialize<'de> for LedgerHash
impl<'de> Deserialize<'de> for LedgerHash
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more