pub struct LedgerSeal {
pub gov_version: u64,
pub sn: u64,
pub prev_ledger_event_hash: DigestIdentifier,
pub protocols_hash: DigestIdentifier,
}Fields
gov_version: u64sn: u64prev_ledger_event_hash: DigestIdentifierprotocols_hash: DigestIdentifierTrait Implementations
Sourceimpl BorshDeserialize for LedgerSeal
impl BorshDeserialize for LedgerSeal
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for LedgerSeal
impl BorshSerialize for LedgerSeal
Sourceimpl Clone for LedgerSeal
impl Clone for LedgerSeal
Sourcefn clone(&self) -> LedgerSeal
fn clone(&self) -> LedgerSeal
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LedgerSeal
impl Debug for LedgerSeal
Sourceimpl<'de> Deserialize<'de> for LedgerSeal
impl<'de> Deserialize<'de> for LedgerSeal
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more