pub struct OpaqueData {
pub subject_id: DigestIdentifier,
pub event_request_timestamp: TimeStamp,
pub signer: PublicKey,
}Fields
subject_id: DigestIdentifierevent_request_timestamp: TimeStampsigner: PublicKeyTrait Implementations
Sourceimpl BorshDeserialize for OpaqueData
impl BorshDeserialize for OpaqueData
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for OpaqueData
impl BorshSerialize for OpaqueData
Sourceimpl Clone for OpaqueData
impl Clone for OpaqueData
Sourcefn clone(&self) -> OpaqueData
fn clone(&self) -> OpaqueData
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for OpaqueData
impl Debug for OpaqueData
Sourceimpl<'de> Deserialize<'de> for OpaqueData
impl<'de> Deserialize<'de> for OpaqueData
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more