pub struct ValidationData {
pub validation_req_signature: Signature,
pub validation_req_hash: DigestIdentifier,
pub validators_signatures: Vec<Signature>,
pub validation_metadata: ValidationMetadata,
}Fields
validation_req_signature: Signaturevalidation_req_hash: DigestIdentifiervalidators_signatures: Vec<Signature>validation_metadata: ValidationMetadataTrait Implementations
Sourceimpl BorshDeserialize for ValidationData
impl BorshDeserialize for ValidationData
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for ValidationData
impl BorshSerialize for ValidationData
Sourceimpl Clone for ValidationData
impl Clone for ValidationData
Sourcefn clone(&self) -> ValidationData
fn clone(&self) -> ValidationData
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ValidationData
impl Debug for ValidationData
Sourceimpl<'de> Deserialize<'de> for ValidationData
impl<'de> Deserialize<'de> for ValidationData
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more