pub struct TimeOut {
pub who: PublicKey,
pub re_trys: u32,
pub timestamp: TimeStamp,
}Fields
who: PublicKeyre_trys: u32timestamp: TimeStampTrait Implementations
Sourceimpl BorshDeserialize for TimeOut
impl BorshDeserialize for TimeOut
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for TimeOut
impl BorshSerialize for TimeOut
Sourceimpl<'de> Deserialize<'de> for TimeOut
impl<'de> Deserialize<'de> for TimeOut
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Ord for TimeOut
impl Ord for TimeOut
Sourceimpl PartialOrd for TimeOut
impl PartialOrd for TimeOut
impl Eq for TimeOut
impl StructuralPartialEq for TimeOut