pub struct TransferData {
pub name: Option<String>,
pub new_owner: PublicKey,
pub actual_owner: PublicKey,
}Fields
name: Option<String>new_owner: PublicKeyactual_owner: PublicKeyTrait Implementations
Sourceimpl BorshDeserialize for TransferData
impl BorshDeserialize for TransferData
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for TransferData
impl BorshSerialize for TransferData
Sourceimpl Clone for TransferData
impl Clone for TransferData
Sourcefn clone(&self) -> TransferData
fn clone(&self) -> TransferData
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TransferData
impl Debug for TransferData
Sourceimpl<'de> Deserialize<'de> for TransferData
impl<'de> Deserialize<'de> for TransferData
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more