pub struct RequestHandler { /* private fields */ }Trait Implementations
Sourceimpl Actor for RequestHandler
impl Actor for RequestHandler
Sourcetype Event = RequestHandlerEvent
type Event = RequestHandlerEvent
The type of events this actor can broadcast to subscribers.
Sourcetype Message = RequestHandlerMessage
type Message = RequestHandlerMessage
The type of messages this actor accepts.
Sourcetype Response = RequestHandlerResponse
type Response = RequestHandlerResponse
The type returned by the actor in response to each message.
Sourcefn get_span(_id: &str, parent_span: Option<Span>) -> Span
fn get_span(_id: &str, parent_span: Option<Span>) -> Span
Creates the tracing span for this actor instance. Read more
Sourcefn pre_start<'life0, 'life1, 'async_trait>(
&'life0 mut self,
ctx: &'life1 mut ActorContext<Self>,
) -> Pin<Box<dyn Future<Output = Result<(), ActorError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
fn pre_start<'life0, 'life1, 'async_trait>(
&'life0 mut self,
ctx: &'life1 mut ActorContext<Self>,
) -> Pin<Box<dyn Future<Output = Result<(), ActorError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
Called once before the actor begins processing messages. Read more
Sourcefn drain_timeout() -> Duration
fn drain_timeout() -> Duration
Maximum time to spend processing critical messages during shutdown before dropping them.
Sourcefn startup_timeout() -> Option<Duration>
fn startup_timeout() -> Option<Duration>
Maximum time to wait for
pre_start to complete; None disables the startup timeout.Sourcefn stop_timeout() -> Option<Duration>
fn stop_timeout() -> Option<Duration>
Maximum time a parent waits for this actor to acknowledge a stop request;
None disables the stop timeout.Sourcefn supervision_strategy() -> SupervisionStrategy
fn supervision_strategy() -> SupervisionStrategy
Returns the supervision strategy applied when this actor fails at startup.
Sourcefn pre_restart<'life0, 'life1, 'life2, 'async_trait>(
&'life0 mut self,
ctx: &'life1 mut ActorContext<Self>,
_error: Option<&'life2 Error>,
) -> Pin<Box<dyn Future<Output = Result<(), Error>> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
Self: 'async_trait,
fn pre_restart<'life0, 'life1, 'life2, 'async_trait>(
&'life0 mut self,
ctx: &'life1 mut ActorContext<Self>,
_error: Option<&'life2 Error>,
) -> Pin<Box<dyn Future<Output = Result<(), Error>> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
Self: 'async_trait,
Called when the actor is about to be restarted after a failure. Read more
Sourcefn pre_stop<'life0, 'life1, 'async_trait>(
&'life0 mut self,
_ctx: &'life1 mut ActorContext<Self>,
) -> Pin<Box<dyn Future<Output = Result<(), Error>> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
Self: 'async_trait,
fn pre_stop<'life0, 'life1, 'async_trait>(
&'life0 mut self,
_ctx: &'life1 mut ActorContext<Self>,
) -> Pin<Box<dyn Future<Output = Result<(), Error>> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
Self: 'async_trait,
Called when the actor is about to stop, before children are stopped. Read more
Sourcefn post_stop<'life0, 'life1, 'async_trait>(
&'life0 mut self,
_ctx: &'life1 mut ActorContext<Self>,
) -> Pin<Box<dyn Future<Output = Result<(), Error>> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
Self: 'async_trait,
fn post_stop<'life0, 'life1, 'async_trait>(
&'life0 mut self,
_ctx: &'life1 mut ActorContext<Self>,
) -> Pin<Box<dyn Future<Output = Result<(), Error>> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
Self: 'async_trait,
Called after all children have stopped and the actor is fully shut down. Override for final cleanup.
Sourceimpl BorshDeserialize for RequestHandler
impl BorshDeserialize for RequestHandler
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for RequestHandler
impl BorshSerialize for RequestHandler
Sourceimpl Clone for RequestHandler
impl Clone for RequestHandler
Sourcefn clone(&self) -> RequestHandler
fn clone(&self) -> RequestHandler
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RequestHandler
impl Debug for RequestHandler
Sourceimpl<'de> Deserialize<'de> for RequestHandler
impl<'de> Deserialize<'de> for RequestHandler
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Handler<RequestHandler> for RequestHandler
impl Handler<RequestHandler> for RequestHandler
Sourcefn handle_message<'life0, 'life1, 'async_trait>(
&'life0 mut self,
_sender: ActorPath,
msg: RequestHandlerMessage,
ctx: &'life1 mut ActorContext<Self>,
) -> Pin<Box<dyn Future<Output = Result<RequestHandlerResponse, ActorError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
fn handle_message<'life0, 'life1, 'async_trait>(
&'life0 mut self,
_sender: ActorPath,
msg: RequestHandlerMessage,
ctx: &'life1 mut ActorContext<Self>,
) -> Pin<Box<dyn Future<Output = Result<RequestHandlerResponse, ActorError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
Sourcefn on_child_fault<'life0, 'life1, 'async_trait>(
&'life0 mut self,
error: ActorError,
ctx: &'life1 mut ActorContext<Self>,
) -> Pin<Box<dyn Future<Output = ChildAction> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
fn on_child_fault<'life0, 'life1, 'async_trait>(
&'life0 mut self,
error: ActorError,
ctx: &'life1 mut ActorContext<Self>,
) -> Pin<Box<dyn Future<Output = ChildAction> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
Called when a child actor fails unrecoverably (panics or exhausts retries). Read more
Sourcefn on_event<'life0, 'life1, 'async_trait>(
&'life0 mut self,
event: RequestHandlerEvent,
ctx: &'life1 mut ActorContext<Self>,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
fn on_event<'life0, 'life1, 'async_trait>(
&'life0 mut self,
event: RequestHandlerEvent,
ctx: &'life1 mut ActorContext<Self>,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
Called when the actor wants to apply an event to its own state; not invoked automatically by the runtime.
Sourcefn on_child_error<'life0, 'life1, 'async_trait>(
&'life0 mut self,
error: Error,
_ctx: &'life1 mut ActorContext<A>,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
Self: 'async_trait,
fn on_child_error<'life0, 'life1, 'async_trait>(
&'life0 mut self,
error: Error,
_ctx: &'life1 mut ActorContext<A>,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
Self: 'async_trait,
Called when a child actor reports an error via
ActorContext::emit_error. Read moreSourceimpl PersistentActor for RequestHandler
impl PersistentActor for RequestHandler
Sourcetype Persistence = LightPersistence
type Persistence = LightPersistence
The persistence strategy (
LightPersistence or FullPersistence).Sourcetype InitParams = (Arc<PublicKey>, (HashAlgorithm, Arc<NetworkSender>))
type InitParams = (Arc<PublicKey>, (HashAlgorithm, Arc<NetworkSender>))
Parameters passed to
create_initial. Use () if no initialization data is needed.Sourcefn update(&mut self, state: Self)
fn update(&mut self, state: Self)
Replaces the current state with
state, used during snapshot recovery. Read moreSourcefn create_initial(params: Self::InitParams) -> Self
fn create_initial(params: Self::InitParams) -> Self
Creates the actor in its default initial state from the given parameters. Read more
Sourcefn initial(params: Self::InitParams) -> InitializedActor<Self>where
Self: Sized,
fn initial(params: Self::InitParams) -> InitializedActor<Self>where
Self: Sized,
Returns an
InitializedActor wrapping the actor’s initial state. Read moreSourcefn compact_on_snapshot() -> bool
fn compact_on_snapshot() -> bool
Whether already snapshotted events should be compacted after a
successful snapshot. Read more
Sourcefn persist<'life0, 'life1, 'life2, 'async_trait>(
&'life0 mut self,
event: &'life1 Self::Event,
ctx: &'life2 mut ActorContext<Self>,
) -> Pin<Box<dyn Future<Output = Result<(), Error>> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
Self: Send + 'async_trait,
fn persist<'life0, 'life1, 'life2, 'async_trait>(
&'life0 mut self,
event: &'life1 Self::Event,
ctx: &'life2 mut ActorContext<Self>,
) -> Pin<Box<dyn Future<Output = Result<(), Error>> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
Self: Send + 'async_trait,
Applies
event to the in-memory state and durably persists it. Read moreSourcefn snapshot<'life0, 'life1, 'async_trait>(
&'life0 self,
ctx: &'life1 mut ActorContext<Self>,
) -> Pin<Box<dyn Future<Output = Result<(), Error>> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
Self: Sync + 'async_trait,
fn snapshot<'life0, 'life1, 'async_trait>(
&'life0 self,
ctx: &'life1 mut ActorContext<Self>,
) -> Pin<Box<dyn Future<Output = Result<(), Error>> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
Self: Sync + 'async_trait,
Sends the current state to the child
store actor to be saved as a snapshot. Read moreSourcefn start_store<'life0, 'life1, 'life2, 'async_trait, C, S>(
&'life0 mut self,
name: &'life1 str,
prefix: Option<String>,
ctx: &'life2 mut ActorContext<Self>,
manager: impl DbManager<C, S> + 'async_trait,
key_box: Option<EncryptedKey>,
) -> Pin<Box<dyn Future<Output = Result<(), Error>> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
C: 'async_trait + Collection,
S: 'async_trait + State,
Self: Send + 'async_trait,
fn start_store<'life0, 'life1, 'life2, 'async_trait, C, S>(
&'life0 mut self,
name: &'life1 str,
prefix: Option<String>,
ctx: &'life2 mut ActorContext<Self>,
manager: impl DbManager<C, S> + 'async_trait,
key_box: Option<EncryptedKey>,
) -> Pin<Box<dyn Future<Output = Result<(), Error>> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
C: 'async_trait + Collection,
S: 'async_trait + State,
Self: Send + 'async_trait,
Creates the child
store actor, opens the storage backend, and recovers any persisted state. Read moreSourceimpl Serialize for RequestHandler
impl Serialize for RequestHandler
Sourceimpl Storable for RequestHandler
impl Storable for RequestHandler
fn init_store<'life0, 'life1, 'life2, 'async_trait>(
&'life0 mut self,
name: &'life1 str,
prefix: Option<String>,
encrypt: bool,
ctx: &'life2 mut ActorContext<Self>,
) -> Pin<Box<dyn Future<Output = Result<(), ActorError>> + Send + 'async_trait>>where
Self: Send + 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,