pub struct RequestTrackingEvent {
pub request_id: String,
pub subject_id: String,
pub sn: Option<u64>,
pub error: String,
pub who: String,
pub abort_type: String,
}Fields
request_id: Stringsubject_id: Stringsn: Option<u64>error: Stringwho: Stringabort_type: StringTrait Implementations
Sourceimpl BorshDeserialize for RequestTrackingEvent
impl BorshDeserialize for RequestTrackingEvent
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for RequestTrackingEvent
impl Clone for RequestTrackingEvent
Sourcefn clone(&self) -> RequestTrackingEvent
fn clone(&self) -> RequestTrackingEvent
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RequestTrackingEvent
impl Debug for RequestTrackingEvent
Sourceimpl<'de> Deserialize<'de> for RequestTrackingEvent
impl<'de> Deserialize<'de> for RequestTrackingEvent
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Serialize for RequestTrackingEvent
impl Serialize for RequestTrackingEvent
impl Event for RequestTrackingEvent