pub struct Metadata {Show 14 fields
pub name: Option<String>,
pub description: Option<String>,
pub subject_id: DigestIdentifier,
pub governance_id: DigestIdentifier,
pub genesis_gov_version: u64,
pub prev_ledger_event_hash: DigestIdentifier,
pub schema_id: SchemaType,
pub namespace: Namespace,
pub sn: u64,
pub creator: PublicKey,
pub owner: PublicKey,
pub new_owner: Option<PublicKey>,
pub active: bool,
pub properties: ValueWrapper,
}Expand description
Subject metadata.
Fields
name: Option<String>description: Option<String>subject_id: DigestIdentifierThe identifier of the subject of the event.
governance_id: DigestIdentifierThe identifier of the governance contract.
genesis_gov_version: u64prev_ledger_event_hash: DigestIdentifierschema_id: SchemaTypeThe identifier of the schema_id used to validate the event.
namespace: NamespaceThe namespace of the subject.
sn: u64The current sequence number of the subject.
creator: PublicKeyThe identifier of the public key of the creator owner.
owner: PublicKeyThe identifier of the public key of the subject owner.
new_owner: Option<PublicKey>active: boolIndicates whether the subject is active or not.
properties: ValueWrapperThe current status of the subject.