pub struct MetadataWithoutProperties {Show 13 fields
pub name: Option<String>,
pub description: Option<String>,
pub subject_id: DigestIdentifier,
pub governance_id: DigestIdentifier,
pub genesis_gov_version: u64,
pub prev_ledger_event_hash: DigestIdentifier,
pub schema_id: SchemaType,
pub namespace: Namespace,
pub sn: u64,
pub creator: PublicKey,
pub owner: PublicKey,
pub new_owner: Option<PublicKey>,
pub active: bool,
}Fields
name: Option<String>description: Option<String>subject_id: DigestIdentifiergovernance_id: DigestIdentifiergenesis_gov_version: u64prev_ledger_event_hash: DigestIdentifierschema_id: SchemaTypenamespace: Namespacesn: u64creator: PublicKeyowner: PublicKeynew_owner: Option<PublicKey>active: boolTrait Implementations
Sourceimpl BorshDeserialize for MetadataWithoutProperties
impl BorshDeserialize for MetadataWithoutProperties
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for MetadataWithoutProperties
impl Clone for MetadataWithoutProperties
Sourcefn clone(&self) -> MetadataWithoutProperties
fn clone(&self) -> MetadataWithoutProperties
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MetadataWithoutProperties
impl Debug for MetadataWithoutProperties
Sourceimpl<'de> Deserialize<'de> for MetadataWithoutProperties
impl<'de> Deserialize<'de> for MetadataWithoutProperties
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<Metadata> for MetadataWithoutProperties
impl From<Metadata> for MetadataWithoutProperties
Sourceimpl Hash for MetadataWithoutProperties
impl Hash for MetadataWithoutProperties
impl Eq for MetadataWithoutProperties
impl StructuralPartialEq for MetadataWithoutProperties