pub struct RequestSubjectData {
pub subject_id: DigestIdentifier,
pub governance_id: DigestIdentifier,
pub namespace: Namespace,
pub schema_id: SchemaType,
pub sn: u64,
pub gov_version: u64,
pub signer: PublicKey,
}Fields
subject_id: DigestIdentifiergovernance_id: DigestIdentifiernamespace: Namespaceschema_id: SchemaTypesn: u64gov_version: u64signer: PublicKeyTrait Implementations
Sourceimpl BorshDeserialize for RequestSubjectData
impl BorshDeserialize for RequestSubjectData
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for RequestSubjectData
impl BorshSerialize for RequestSubjectData
Sourceimpl Clone for RequestSubjectData
impl Clone for RequestSubjectData
Sourcefn clone(&self) -> RequestSubjectData
fn clone(&self) -> RequestSubjectData
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RequestSubjectData
impl Debug for RequestSubjectData
Sourceimpl<'de> Deserialize<'de> for RequestSubjectData
impl<'de> Deserialize<'de> for RequestSubjectData
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more