pub struct SignedLedger(pub Signed<Ledger>);Tuple Fields
0: Signed<Ledger>Trait Implementations
Sourceimpl BorshDeserialize for SignedLedger
impl BorshDeserialize for SignedLedger
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for SignedLedger
impl BorshSerialize for SignedLedger
Sourceimpl Clone for SignedLedger
impl Clone for SignedLedger
Sourcefn clone(&self) -> SignedLedger
fn clone(&self) -> SignedLedger
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SignedLedger
impl Debug for SignedLedger
Sourceimpl Deref for SignedLedger
impl Deref for SignedLedger
Sourceimpl<'de> Deserialize<'de> for SignedLedger
impl<'de> Deserialize<'de> for SignedLedger
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Serialize for SignedLedger
impl Serialize for SignedLedger
impl Event for SignedLedger