pub struct SubjectMetadata {
pub name: Option<String>,
pub description: Option<String>,
pub subject_id: DigestIdentifier,
pub schema_id: SchemaType,
pub owner: PublicKey,
pub new_owner: Option<PublicKey>,
pub prev_ledger_event_hash: DigestIdentifier,
pub creator: PublicKey,
pub active: bool,
pub sn: u64,
}Fields
name: Option<String>The name of the subject.
description: Option<String>The description of the subject.
subject_id: DigestIdentifierThe identifier of the subject.
schema_id: SchemaTypeowner: PublicKeyThe identifier of the public key of the subject owner.
new_owner: Option<PublicKey>The identifier of the public key of the new subject owner.
prev_ledger_event_hash: DigestIdentifiercreator: PublicKeyThe identifier of the public key of the subject creator.
active: boolIndicates whether the subject is active or not.
sn: u64The current sequence number of the subject.
Implementations