pub struct CurrentRequestRoles {
pub evaluation: RoleDataRegister,
pub approval: RoleDataRegister,
}Expand description
A struct representing a ValiWorker actor.
Fields
evaluation: RoleDataRegisterapproval: RoleDataRegisterTrait Implementations
Sourceimpl BorshDeserialize for CurrentRequestRoles
impl BorshDeserialize for CurrentRequestRoles
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for CurrentRequestRoles
impl BorshSerialize for CurrentRequestRoles
Sourceimpl Clone for CurrentRequestRoles
impl Clone for CurrentRequestRoles
Sourcefn clone(&self) -> CurrentRequestRoles
fn clone(&self) -> CurrentRequestRoles
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CurrentRequestRoles
impl Debug for CurrentRequestRoles
Sourceimpl<'de> Deserialize<'de> for CurrentRequestRoles
impl<'de> Deserialize<'de> for CurrentRequestRoles
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more