pub struct ValiWorker {
pub node_key: PublicKey,
pub our_key: Arc<PublicKey>,
pub init_state: Option<ValueWrapper>,
pub governance_id: DigestIdentifier,
pub gov_version: u64,
pub sn: u64,
pub hash: HashAlgorithm,
pub network: Arc<NetworkSender>,
pub current_roles: CurrentWorkerRoles,
pub stop: bool,
}Fields
node_key: PublicKeyour_key: Arc<PublicKey>init_state: Option<ValueWrapper>governance_id: DigestIdentifiergov_version: u64sn: u64hash: HashAlgorithmnetwork: Arc<NetworkSender>current_roles: CurrentWorkerRolesstop: boolTrait Implementations
Sourceimpl Actor for ValiWorker
impl Actor for ValiWorker
Sourcetype Message = ValiWorkerMessage
type Message = ValiWorkerMessage
The type of messages this actor accepts.
Sourcefn get_span(id: &str, parent_span: Option<Span>) -> Span
fn get_span(id: &str, parent_span: Option<Span>) -> Span
Creates the tracing span for this actor instance. Read more
Sourcefn drain_timeout() -> Duration
fn drain_timeout() -> Duration
Maximum time to spend processing critical messages during shutdown before dropping them.
Sourcefn startup_timeout() -> Option<Duration>
fn startup_timeout() -> Option<Duration>
Maximum time to wait for
pre_start to complete; None disables the startup timeout.Sourcefn stop_timeout() -> Option<Duration>
fn stop_timeout() -> Option<Duration>
Maximum time a parent waits for this actor to acknowledge a stop request;
None disables the stop timeout.Sourcefn supervision_strategy() -> SupervisionStrategy
fn supervision_strategy() -> SupervisionStrategy
Returns the supervision strategy applied when this actor fails at startup.
Sourcefn pre_start<'life0, 'life1, 'async_trait>(
&'life0 mut self,
_context: &'life1 mut ActorContext<Self>,
) -> Pin<Box<dyn Future<Output = Result<(), Error>> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
Self: 'async_trait,
fn pre_start<'life0, 'life1, 'async_trait>(
&'life0 mut self,
_context: &'life1 mut ActorContext<Self>,
) -> Pin<Box<dyn Future<Output = Result<(), Error>> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
Self: 'async_trait,
Called once before the actor begins processing messages. Read more
Sourcefn pre_restart<'life0, 'life1, 'life2, 'async_trait>(
&'life0 mut self,
ctx: &'life1 mut ActorContext<Self>,
_error: Option<&'life2 Error>,
) -> Pin<Box<dyn Future<Output = Result<(), Error>> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
Self: 'async_trait,
fn pre_restart<'life0, 'life1, 'life2, 'async_trait>(
&'life0 mut self,
ctx: &'life1 mut ActorContext<Self>,
_error: Option<&'life2 Error>,
) -> Pin<Box<dyn Future<Output = Result<(), Error>> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
Self: 'async_trait,
Called when the actor is about to be restarted after a failure. Read more
Sourcefn pre_stop<'life0, 'life1, 'async_trait>(
&'life0 mut self,
_ctx: &'life1 mut ActorContext<Self>,
) -> Pin<Box<dyn Future<Output = Result<(), Error>> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
Self: 'async_trait,
fn pre_stop<'life0, 'life1, 'async_trait>(
&'life0 mut self,
_ctx: &'life1 mut ActorContext<Self>,
) -> Pin<Box<dyn Future<Output = Result<(), Error>> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
Self: 'async_trait,
Called when the actor is about to stop, before children are stopped. Read more
Sourcefn post_stop<'life0, 'life1, 'async_trait>(
&'life0 mut self,
_ctx: &'life1 mut ActorContext<Self>,
) -> Pin<Box<dyn Future<Output = Result<(), Error>> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
Self: 'async_trait,
fn post_stop<'life0, 'life1, 'async_trait>(
&'life0 mut self,
_ctx: &'life1 mut ActorContext<Self>,
) -> Pin<Box<dyn Future<Output = Result<(), Error>> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
Self: 'async_trait,
Called after all children have stopped and the actor is fully shut down. Override for final cleanup.
Sourceimpl Clone for ValiWorker
impl Clone for ValiWorker
Sourcefn clone(&self) -> ValiWorker
fn clone(&self) -> ValiWorker
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ValiWorker
impl Debug for ValiWorker
Sourceimpl Handler<ValiWorker> for ValiWorker
impl Handler<ValiWorker> for ValiWorker
Sourcefn handle_message<'life0, 'life1, 'async_trait>(
&'life0 mut self,
_sender: ActorPath,
msg: ValiWorkerMessage,
ctx: &'life1 mut ActorContext<Self>,
) -> Pin<Box<dyn Future<Output = Result<(), ActorError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
fn handle_message<'life0, 'life1, 'async_trait>(
&'life0 mut self,
_sender: ActorPath,
msg: ValiWorkerMessage,
ctx: &'life1 mut ActorContext<Self>,
) -> Pin<Box<dyn Future<Output = Result<(), ActorError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
Sourcefn on_child_fault<'life0, 'life1, 'async_trait>(
&'life0 mut self,
error: ActorError,
ctx: &'life1 mut ActorContext<Self>,
) -> Pin<Box<dyn Future<Output = ChildAction> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
fn on_child_fault<'life0, 'life1, 'async_trait>(
&'life0 mut self,
error: ActorError,
ctx: &'life1 mut ActorContext<Self>,
) -> Pin<Box<dyn Future<Output = ChildAction> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
Called when a child actor fails unrecoverably (panics or exhausts retries). Read more
Sourcefn on_event<'life0, 'life1, 'async_trait>(
&'life0 mut self,
_event: <A as Actor>::Event,
_ctx: &'life1 mut ActorContext<A>,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
Self: 'async_trait,
fn on_event<'life0, 'life1, 'async_trait>(
&'life0 mut self,
_event: <A as Actor>::Event,
_ctx: &'life1 mut ActorContext<A>,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
Self: 'async_trait,
Called when the actor wants to apply an event to its own state; not invoked automatically by the runtime.
Sourcefn on_child_error<'life0, 'life1, 'async_trait>(
&'life0 mut self,
error: Error,
_ctx: &'life1 mut ActorContext<A>,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
Self: 'async_trait,
fn on_child_error<'life0, 'life1, 'async_trait>(
&'life0 mut self,
error: Error,
_ctx: &'life1 mut ActorContext<A>,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
Self: 'async_trait,
Called when a child actor reports an error via
ActorContext::emit_error. Read moreimpl NotPersistentActor for ValiWorker